@@ -38,6 +38,11 @@ static GtkWidget *main_window;
 static GtkWidget *about_dialog;
 static GtkButton *rescan_button;
 
+gboolean
+on_delete_event (GtkWidget *widget,
+                 GdkEvent  *event,
+                 gpointer   user_data);
+
 G_MODULE_EXPORT
 gboolean
 on_delete_event (GtkWidget *widget,
@@ -50,7 +55,7 @@ on_delete_event (GtkWidget *widget,
 }
 
 static void
-setup_icons (GtkBuilder *builder)
+setup_icons (GtkBuilder *object)
 {
         GdkPixbuf *icon_pixbuf;
         GtkWidget *volume_min;
@@ -81,10 +86,12 @@ setup_icons (GtkBuilder *builder)
 }
 
 gboolean
-init_ui ()
+init_ui (void)
 {
         gint window_width, window_height;
         GError *error = NULL;
+        double w = 0.0;
+        double h = 0.0;
 
         builder = gtk_builder_new ();
         g_assert (builder != NULL);
@@ -110,8 +117,18 @@ init_ui ()
         g_assert (rescan_button != NULL);
 
         /* 40% of the screen but don't get bigger than 1000x800 */
-        window_width = CLAMP ((gdk_screen_width () * 40 / 100), 10, 1000);
-        window_height = CLAMP ((gdk_screen_height () * 40 / 100), 10, 800);
+        w = gdk_screen_width () * 0.4;
+        h = gdk_screen_height () * 0.4;
+
+        /* Keep 5/4 aspect */
+        if (w/h > 1.25) {
+                h = w / 1.25;
+        } else {
+                w = h * 1.25;
+        }
+
+        window_width = CLAMP ((int) w, 10, 1000);
+        window_height = CLAMP ((int) h, 10, 800);
         gtk_window_set_default_size (GTK_WINDOW (main_window),
                                      window_width,
                                      window_height);
