@@ -51,6 +51,8 @@ static GOptionEntry entries[] =
 
 static GUPnPContextManager *context_manager;
 
+void application_exit (void);
+
 static void
 dms_proxy_available_cb (GUPnPControlPoint *cp,
                         GUPnPDeviceProxy  *proxy)
@@ -83,19 +85,18 @@ static void
 on_rescan_button_clicked (GtkButton *button,
                           gpointer user_data)
 {
-        GSSDPResourceBrowser *browser = GSSDP_RESOURCE_BROWSER (user_data);
+        GUPnPContextManager *cm = GUPNP_CONTEXT_MANAGER (user_data);
 
-        gssdp_resource_browser_rescan (browser);
+        gupnp_context_manager_rescan_control_points (cm);
 }
 
 static void
-on_context_available (GUPnPContextManager *context_manager,
+on_context_available (GUPnPContextManager *cm,
                       GUPnPContext        *context,
                       gpointer             user_data)
 {
         GUPnPControlPoint *dms_cp;
         GUPnPControlPoint *dmr_cp;
-        GtkButton *button;
 
         dms_cp = gupnp_control_point_new (context, MEDIA_SERVER);
         dmr_cp = gupnp_control_point_new (context, MEDIA_RENDERER);
@@ -117,18 +118,11 @@ on_context_available (GUPnPContextManager *context_manager,
                           G_CALLBACK (dmr_proxy_unavailable_cb),
                           NULL);
 
-        button = get_rescan_button ();
-
         gssdp_resource_browser_set_active (GSSDP_RESOURCE_BROWSER (dms_cp),
                                            TRUE);
         gssdp_resource_browser_set_active (GSSDP_RESOURCE_BROWSER (dmr_cp),
                                            TRUE);
 
-        g_signal_connect (button, "clicked",
-                          G_CALLBACK (on_rescan_button_clicked), dms_cp);
-        g_signal_connect (button, "clicked",
-                          G_CALLBACK (on_rescan_button_clicked), dmr_cp);
-
         /* Let context manager take care of the control point life cycle */
         gupnp_context_manager_manage_control_point (context_manager, dms_cp);
         gupnp_context_manager_manage_control_point (context_manager, dmr_cp);
@@ -142,6 +136,7 @@ static gboolean
 init_upnp (int port)
 {
         GUPnPWhiteList *white_list;
+        GtkButton *button;
 
 #if !GLIB_CHECK_VERSION(2, 35, 0)
         g_type_init ();
@@ -162,6 +157,12 @@ init_upnp (int port)
                           G_CALLBACK (on_context_available),
                           NULL);
 
+        button = get_rescan_button ();
+        g_signal_connect (G_OBJECT (button),
+                          "clicked",
+                          G_CALLBACK (on_rescan_button_clicked),
+                          context_manager);
+
         return TRUE;
 }
 
